@@ -549,7 +549,7 @@ class ImageReader(object):
 
     This class is meant to be harnessed to a scope like this:
 
-    >>> with GetImageReader(path) as reader:
+    >>> with ImageReader(path) as reader:
     >>>     ....
 
     It uses `__enter__` and `__exit__` to manage the random access stream
@@ -593,7 +593,7 @@ class ImageReader(object):
                             omero_logout()
                             omero_login()
                         else:
-                            logger.warn(e.message)
+                            logger.warn(e)
                             for line in traceback.format_exc().split("\n"):
                                 logger.warn(line)
                             if jutil.is_instance_of(
@@ -732,7 +732,7 @@ class ImageReader(object):
         try:
             self.rdr.setId(self.path)
         except jutil.JavaException as e:
-            logger.warn(e.message)
+            logger.warn(e)
             for line in traceback.format_exc().split("\n"):
                 logger.warn(line)
             je = e.throwable
@@ -748,8 +748,8 @@ class ImageReader(object):
                 je, "java/io/FileNotFoundException"):
                 raise IOError(
                     errno.ENOENT,
-                    "The file, \"%s\", does not exist." % path,
-                    path)
+                    "The file, \"%s\", does not exist." % self.path,
+                    self.path)
             e2 = IOError(
                 errno.EINVAL, "Could not load the file as an image (see log for details)",
                 self.path.encode('utf-8'))
